@@ -34,6 +34,7 @@ except ImportError:
 
 try:
     import pyfftw
+
     pyfftw_available = True
 except ImportError:
     log.info("pyfftw not available, will use numpy")
@@ -83,7 +84,9 @@ class ContextCpu(XContext):
 
     """
 
-    nplike_array_type = np.ndarray
+    @property
+    def nplike_array_type(self):
+        return np.ndarray
 
     def __init__(self, omp_num_threads=0):
         super().__init__()
