@@ -33,7 +33,7 @@ except ImportError:
 
 
 cudaheader = [
-"""\
+    """\
 typedef signed long long int64_t;  //only_for_context cuda
 typedef signed char      int8_t;   //only_for_context cuda
 typedef unsigned int     uint32_t; //only_for_context cuda
@@ -62,7 +62,9 @@ class ContextCupy(XContext):
 
     """
 
-    nplike_array_type = cupy.ndarray
+    @property
+    def nplike_array_type(self):
+        return cupy.ndarray
 
     def __init__(self, default_block_size=256, device=None):
 
